@@ -94,7 +94,7 @@ if args.state:
     relay = Relay.from_state(args.state, config=args.config)
 elif args.config:
     relay = Relay.from_config(args.config)
-elif args.port > 0 and args.network:
+elif args.port > 0:
     relay = Relay(args.port, 
                     save_to=args.saveloc, clear_time=args.timeout)
 else:
